import { buildFile, getPagePaths, getStylePath } from './utils';
import { format } from 'prettier';
import Root from './root';
import { writeFileSync } from 'node:fs';

export const buildPage = async (page: string) => {
  const { pagePath, tmpJsPath, pageOutputHtmlPath } = getPagePaths(page);

  await buildFile(pagePath, tmpJsPath);

  const { default: Page } = await import(tmpJsPath);
  const html = Page.default();
  let stylePaths: string[] = getStylePath(tmpJsPath, pageOutputHtmlPath);

  const formattedHtml = await format(
    <Root title="My App" stylePaths={stylePaths} scriptPaths={[]}>
      {html}
    </Root>,
    { parser: 'html' },
  );

  writeFileSync(pageOutputHtmlPath, formattedHtml);
};
